summaryrefslogtreecommitdiff
path: root/include/mbgl/storage/file_source.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'include/mbgl/storage/file_source.hpp')
-rw-r--r--include/mbgl/storage/file_source.hpp10
1 files changed, 3 insertions, 7 deletions
diff --git a/include/mbgl/storage/file_source.hpp b/include/mbgl/storage/file_source.hpp
index 8d08315cd9..e572776af2 100644
--- a/include/mbgl/storage/file_source.hpp
+++ b/include/mbgl/storage/file_source.hpp
@@ -5,17 +5,13 @@
#include <mbgl/storage/resource.hpp>
#include <mbgl/util/noncopyable.hpp>
+#include <mbgl/util/async_request.hpp>
#include <functional>
#include <memory>
namespace mbgl {
-class FileRequest : private util::noncopyable {
-public:
- virtual ~FileRequest() = default;
-};
-
class FileSource : private util::noncopyable {
public:
virtual ~FileSource() = default;
@@ -24,10 +20,10 @@ public:
// Request a resource. The callback will be called asynchronously, in the same
// thread as the request was made. This thread must have an active RunLoop. The
// request may be cancelled before completion by releasing the returned FileRequest.
// If the request is cancelled before the callback is executed, the callback will
// not be executed.
- virtual std::unique_ptr<FileRequest> request(const Resource&, Callback) = 0;
+ virtual std::unique_ptr<AsyncRequest> request(const Resource&, Callback) = 0;
};
} // namespace mbgl
@@ -24,10 +20,10 @@ public:
// Request a resource. The callback will be called asynchronously, in the same
// thread as the request was made. This thread must have an active RunLoop. The
- // request may be cancelled before completion by releasing the returned FileRequest.
+ // request may be cancelled before completion by releasing the returned AsyncRequest.
// If the request is cancelled before the callback is executed, the callback will
// not be executed.